@@ -7,11 +7,11 @@ Posy::Plugin::TextToHTML - Posy plugin to convert plain text files to HTML
 
 =head1 VERSION
 
-This describes version B<0.05> of Posy::Plugin::TextToHTML.
+This describes version B<0.10> of Posy::Plugin::TextToHTML.
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.10';
 
 =head1 SYNOPSIS
 
@@ -135,6 +135,8 @@ sub parse_entry {
 
 =head1 REQUIRES
 
+    Posy
+    Posy::Core
     HTML::TextToHTML
 
     Test::More
